@@ -2,31 +2,34 @@ import os
 import json
 import csv
 import jieba.analyse
+from itertools import permutations
 
 
 class CrawledContent:
 
-    def __init__(self, analyse, export_file):
-        self.analyse = analyse
+    def __init__(self, export_file, analyse):
         self.export_file = export_file
+        self.analyse = analyse
         self.next = {}
         self.result = {}
 
     @classmethod
     def user_input(cls):
-        while 1:
-            try:
-                analyse = int(input('需要文本分析提取关键词则键入1，否则键入0'))
-                break
-            except ValueError:
-                print("请重新输入")
         while 1:
             export_file = input('请输入导出文件，支持csv/json')
             if export_file.split('.')[-1] in ['csv', 'json']:
                 break
+
+        a_list = ['', 'a', 'n', 'v'] + list(map(lambda x: ','.join(x), list(permutations(['n', 'a', 'v'], 2)) +
+                                                list(permutations(['n', 'a', 'v'], 3))))
+        while 1:
+            analyse = input('请输入需要搜索的关键词类型并用逗号分隔，如无直接回车')
+            if analyse in a_list:
+                break
+
         return cls(
-            analyse,
-            export_file
+            export_file,
+            analyse
         )
 
     def update(self, keyword, result_list):
@@ -52,17 +55,19 @@ class CrawledContent:
             with open(self.export_file, 'w', encoding='utf-8') as json_file:
                 json.dump(result_dict, json_file, ensure_ascii=False, indent=4)
 
-    def extract_tags(self, idx=-1, topK=3, POS=('n', 'a', 'v')):
+    def extract_tags(self, idx=2, topK=3):
+        global tags
         key = list(self.next.keys())[0]
         val = self.next[key]
-        POS = list(POS)
         POS_dict = {'n': ('n', 'nr', 'ns', 'nt', 'nz'),
                     'a': ('a', 'ad', 'an'),
                     'v': ('v', 'vd', 'vn')}
         for k in range(len(val)):
-            for p in POS:
+            for p in self.analyse.split(','):
                 try:
                     tags = jieba.analyse.extract_tags(val[k][idx], topK=topK, allowPOS=POS_dict.get(p))
-                    self.next[key][k].append(' '.join(tags))
+                    tags = ' '.join(tags)
                 except AttributeError:
-                    self.next[key][k].append(' ')
+                    tags = ' '
+                finally:
+                    self.next[key][k].append(tags)
